@@ -1,12 +1,12 @@
 package FCGI::EV::Std::Nonblock;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = qv('1.3.2');    # update POD & Changes & README
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken refaddr );
 
 use FCGI::EV::Std;
@@ -14,10 +14,10 @@ $FCGI::EV::Std::BLOCKING= 0;
 $FCGI::EV::Std::MAIN    = \&new;
 $FCGI::EV::Std::HUP     = \&HUP;
 
-my $cb_start            = \&main::START;
-my $cb_pre              = \&main::PRE;
-my $cb_post             = \&main::POST;
-my $cb_error            = \&main::ERROR;
+my $CB_START            = \&main::START;
+my $CB_PRE              = \&main::PRE;
+my $CB_POST             = \&main::POST;
+my $CB_ERROR            = \&main::ERROR;
 #my $HUP                 = undef;
 
 my (%Active, %Server);
@@ -29,7 +29,7 @@ sub new {
     $Active{ refaddr($self)     } = $server;
     $Server{ refaddr($server)   } = $self;
     weaken( $Active{ refaddr($self) } );
-    $self->_wrapper($cb_start);
+    $self->_wrapper($CB_START);
     return;
 }
 
@@ -76,12 +76,12 @@ sub wrap_cb {
 sub _wrapper {
     my ($this, $cb, @p) = @_;
 
-    $cb_pre->($this);
+    $CB_PRE->($this);
     my $err = eval { $cb->($this, @p); 1 } ? undef : $@;
-    $cb_post->($this);
+    $CB_POST->($this);
 
     if (defined $err) {
-        $cb_error->($this, $err);
+        $CB_ERROR->($this, $err);
     }
     return;
 }
@@ -90,6 +90,10 @@ sub _wrapper {
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
+=for stopwords PRE
+
 =head1 NAME
 
 FCGI::EV::Std::Nonblock - Ease non-blocking CGI using FCGI::EV::Std
@@ -97,7 +101,7 @@ FCGI::EV::Std::Nonblock - Ease non-blocking CGI using FCGI::EV::Std
 
 =head1 VERSION
 
-This document describes FCGI::EV::Std::Nonblock version 1.3.2
+This document describes FCGI::EV::Std::Nonblock version v2.0.0
 
 
 =head1 SYNOPSIS
@@ -200,67 +204,63 @@ The ERROR hook will two parameters: $this and $exception (stored copy of $@).
 =back
 
 
-=head1 DIAGNOSTICS
+=head1 SUPPORT
 
-None.
+=head2 Bugs / Feature Requests
 
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-FCGI-EV-Std/issues>.
+You will be notified automatically of any progress on your issue.
 
-=head1 CONFIGURATION AND ENVIRONMENT
+=head2 Source Code
 
-FCGI::EV::Std::Nonblock requires no configuration files or environment variables.
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
 
+L<https://github.com/powerman/perl-FCGI-EV-Std>
 
-=head1 DEPENDENCIES
+    git clone https://github.com/powerman/perl-FCGI-EV-Std.git
 
- version
+=head2 Resources
 
+=over
 
-=head1 INCOMPATIBILITIES
+=item * MetaCPAN Search
 
-None reported.
+L<https://metacpan.org/search?q=FCGI-EV-Std>
 
+=item * CPAN Ratings
 
-=head1 BUGS AND LIMITATIONS
+L<http://cpanratings.perl.org/dist/FCGI-EV-Std>
 
-No bugs have been reported.
+=item * AnnoCPAN: Annotated CPAN documentation
 
-Please report any bugs or feature requests to
-C<bug-fcgi-ev-std-nonblock@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+L<http://annocpan.org/dist/FCGI-EV-Std>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=FCGI-EV-Std>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/FCGI-EV-Std>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009, Alex Efros C<< <powerman-asdf@ya.ru> >>. All rights reserved.
+This software is Copyright (c) 2009 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
